@font-face{
    font-family: 'Source Code Variable';
    font-weight: 200 900;
    font-style: normal;
    font-stretch: normal;
    src: url('./WOFF2/VAR/SourceCodeVariable-Roman.ttf.woff2') format('woff2'),
         url('./WOFF/VAR/SourceCodeVariable-Roman.ttf.woff') format('woff'),
         url('./VAR/SourceCodeVariable-Roman.ttf') format('truetype');
}

@font-face{
    font-family: 'Source Code Variable';
    font-weight: 200 900;
    font-style: italic;
    font-stretch: normal;
    src: url('./WOFF2/VAR/SourceCodeVariable-Italic.ttf.woff2') format('woff2'),
         url('./WOFF/VAR/SourceCodeVariable-Italic.ttf.woff') format('woff'),
         url('./VAR/SourceCodeVariable-Italic.ttf') format('truetype');
}
